@@ -57,8 +57,7 @@ rss_parse <- function(doc){
       feed_title = xml2::xml_text(xml2::xml_find_first(channel, "id")),
       feed_link = xml2::xml_text(xml2::xml_find_first(channel, "link")),
       feed_description = xml2::xml_text(xml2::xml_find_first(channel, "description")),
-      feed_last_updated = xml2::xml_text(xml2::xml_find_first(channel,
-                                                              "lastBuildDate")) %>%
+      feed_last_updated = xml2::xml_text(xml2::xml_find_first(channel, "lastBuildDate")) %>%
         lubridate::parse_date_time(orders = formats),
       feed_language = xml2::xml_text(xml2::xml_find_first(channel, "language")),
       feed_update_period = xml2::xml_text(xml2::xml_find_first(channel, "updatePeriod")),
@@ -67,11 +66,17 @@ rss_parse <- function(doc){
       item_date_published = xml2::xml_text(xml2::xml_find_first(site, "pubDate")) %>%
         lubridate::parse_date_time(orders = formats),
       item_description = xml2::xml_text(xml2::xml_find_first(site, "description")),
-      item_categories = xml2::xml_find_all(site, "category/..") %>%
-        lapply(function(item) xml2::xml_text(xml2::xml_find_all(item, "category"))),
       item_link = xml2::xml_text(xml2::xml_find_first(site, "link"))
     )})
 
+    if(length(xml2::xml_find_all(site, "category")) > 0){
+      rss <- rss %>%
+        dplyr::mutate(
+          item_categories = xml2::xml_find_all(site, "category") %>%
+            lapply(function(item) xml2::xml_text(xml2::xml_find_all(item, "category")))
+      )
+    }
+
       suppressWarnings(
         res$feed_update_period[is.na(res$feed_update_period)] <- xml2::xml_text(
           xml2::xml_find_first(channel, "sy:updatePeriod"))
